# Changes

## 2022.7.24

* Bumped dependencies for development and test
* Moved documentation to https://codes.dilettant.life/docs/nineties
* Moved tracker to https://todo.sr.ht/~sthagen/nineties
* Moved normative source repo to https://git.sr.ht/~sthagen/nineties
* Added test coverage link to documentation and coverage to https://codes.dilettant.life/coverage/nineties

## Older
### 2021.5.13 (0.0.6)

* Sixth release to PyPI with compatibility info changes and pinning of faker dependency

### 2019.11.17 (0.0.5)

* Fifth release to PyPI with file system interfacing list and triage functions as well as unit tests

### 2019.11.14 (0.0.4)

* Fourth release to PyPI with new issue key parsers, sorters and unit tests as well as the new CHANGELOG

### 2019.10.28 (0.0.3)

* Third release to PyPI with changed github account.

### 2019.10.27 (0.0.2)

* Second release to PyPI.

### 2019.10.24 (0.0.1)

* First release on PyPI.
